from .src.progb.main import Bar

__version__ = "0.0.6"
__author__ = {"Henry Cook":"henryscookolaizola@gmail.com"}